@@ -50,6 +50,7 @@ class RecordWriter
     bool inline writeRecordUnsafe(const UnresolvedNativeFrame& record);
     bool inline writeRecordUnsafe(const MemoryMapStart&);
     bool writeHeader(bool seek_to_start);
+    bool writeTrailer();
 
     std::unique_lock<std::mutex> acquireLock();
     std::unique_ptr<RecordWriter> cloneInChildProcess();
@@ -161,7 +162,7 @@ bool inline RecordWriter::writeRecordUnsafe(const MemoryRecord& record)
 {
     RecordTypeAndFlags token{RecordType::MEMORY_RECORD, 0};
     return writeSimpleType(token) && writeVarint(record.rss)
-           && writeVarint(record.ms_since_epoch - d_stats.start_time);
+           && writeVarint(record.ms_since_epoch - d_stats.start_time) && d_sink->flush();
 }
 
 bool inline RecordWriter::writeRecordUnsafe(const ContextSwitch& record)
@@ -199,7 +200,7 @@ bool inline RecordWriter::writeRecordUnsafe(const NativeAllocationRecord& record
 bool inline RecordWriter::writeRecordUnsafe(const pyrawframe_map_val_t& item)
 {
     d_stats.n_frames += 1;
-    RecordTypeAndFlags token{RecordType::FRAME_INDEX, 0};
+    RecordTypeAndFlags token{RecordType::FRAME_INDEX, !item.second.is_entry_frame};
     return writeSimpleType(token) && writeIntegralDelta(&d_last.python_frame_id, item.first)
            && writeString(item.second.function_name) && writeString(item.second.filename)
            && writeIntegralDelta(&d_last.python_line_number, item.second.lineno);
